# PyNeuphonic
The official Neuphonic Python library providing simple, convenient access to the Neuphonic text-to-speech websocket
API from any Python 3.9+ application.

## Getting Started
This repository is an early implementation of the Neuphonic python SDK to interact with the websocket API for text to
speech functionality.

### Installation
Install this package into your environment using your chosen package manager:

**pip**:
```bash
pip install pyneuphonic
```
**poetry**
```bash
poetry add pyneuphonic
```

### Documentation
See [https://docs.neuphonic.com](https://docs.neuphonic.com) for the complete API documentation.
